@@ -16,12 +16,12 @@
 import argparse
 import sys
 
-from fastestimator.cli.history import configure_history_parser
 from fastestimator.cli.logs import configure_log_parser
+from fastestimator.cli.run import configure_run_parser
 from fastestimator.cli.train import configure_test_parser, configure_train_parser
 
 
-def run(argv) -> None:
+def run_main(argv) -> None:
     """A function which invokes the various argument parsers and then runs the requested subroutine.
     """
     parser = argparse.ArgumentParser(allow_abbrev=False)
@@ -32,13 +32,13 @@ def run(argv) -> None:
     configure_train_parser(subparsers)
     configure_test_parser(subparsers)
     configure_log_parser(subparsers)
-    configure_history_parser(subparsers)
+    configure_run_parser(subparsers)
     args, unknown = parser.parse_known_args(argv)
     args.func(vars(args), unknown)
 
 
 def main() -> None:
-    run(sys.argv[1:])
+    run_main(sys.argv[1:])
 
 
 if __name__ == '__main__':
