@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-import inspect
 import os
 import random
 from collections import ChainMap
@@ -28,20 +27,20 @@ import fastestimator as fe
 from fastestimator.backend.to_shape import to_shape
 from fastestimator.backend.to_tensor import to_tensor
 from fastestimator.backend.to_type import to_type
-from fastestimator.dataset.batch_dataset import BatchDataset
+from fastestimator.dataset.op_dataset import OpDataset
 from fastestimator.network import BaseNetwork, TFNetwork, TorchNetwork
 from fastestimator.pipeline import Pipeline
 from fastestimator.schedule.schedule import Scheduler, get_current_items, get_signature_epochs
-from fastestimator.summary.history import HistoryRecorder
 from fastestimator.summary.system import Summary, System
 from fastestimator.trace.io.best_model_saver import BestModelSaver
 from fastestimator.trace.io.model_saver import ModelSaver
 from fastestimator.trace.io.restore_wizard import RestoreWizard
 from fastestimator.trace.io.traceability import Traceability
-from fastestimator.trace.trace import EvalEssential, Logger, TestEssential, Trace, TrainEssential, sort_traces
+from fastestimator.trace.trace import EvalEssential, Logger, PerDSTrace, TestEssential, Trace, TrainEssential, \
+    sort_traces
 from fastestimator.util.data import Data
 from fastestimator.util.traceability_util import traceable
-from fastestimator.util.util import NonContext, Suppressor, draw, to_list, to_set
+from fastestimator.util.util import Suppressor, draw, to_list, to_set
 
 
 @traceable()
@@ -68,7 +67,6 @@ class Estimator:
     monitor_names: Set[str]
     traces_in_use: List[Union[Trace, Scheduler[Trace]]]
     system: System
-    filepath: str
 
     def __init__(self,
                  pipeline: Pipeline,
@@ -80,7 +78,6 @@ class Estimator:
                  log_steps: Optional[int] = 100,
                  monitor_names: Union[None, str, Iterable[str]] = None):
         self.traces_in_use = []
-        self.filepath = os.path.realpath(inspect.stack()[2].filename)  # Record this for history tracking
         assert log_steps is None or log_steps >= 0, \
             "log_steps must be None or positive (or 0 to disable only train logging)"
         self.monitor_names = to_set(monitor_names) | network.get_loss_keys()
@@ -105,7 +102,7 @@ class Estimator:
     def traces(self) -> List[Union[Trace, Scheduler[Trace]]]:
         return self.system.traces
 
-    def fit(self, summary: Optional[str] = None, warmup: Union[bool, str] = True) -> Optional[Summary]:
+    def fit(self, summary: Optional[str] = None, warmup: bool = True, eager: bool = False) -> Optional[Summary]:
         """Train the network for the number of epochs specified by the estimator's constructor.
 
         Args:
@@ -114,7 +111,9 @@ class Estimator:
             warmup: Whether to perform warmup before training begins. The warmup procedure will test one step at every
                 epoch where schedulers cause the execution graph to change. This can take some time up front, but can
                 also save significant heartache on epoch 300 when the training unexpectedly fails due to a tensor size
-                mismatch. When set to "debug", the warmup will be performed in eager execution for easier debugging.
+                mismatch.
+            eager: Whether to run the training in eager mode. This is only related to TensorFlow training because
+                PyTorch by nature is always in eager mode.
 
         Returns:
             A summary object containing the training history for this session iff a `summary` name was provided.
@@ -123,12 +122,12 @@ class Estimator:
         self.system.reset(summary, self.fe_summary())
         self._prepare_traces(run_modes={"train", "eval"})
         if warmup:
-            self._warmup(warmup=warmup)
-        self._start(run_modes={"train", "eval"})
+            self._warmup(eager=eager)
+        self._start(run_modes={"train", "eval"}, eager=eager)
         return self.system.summary or None
 
     def _prepare_traces(self, run_modes: Set[str]) -> None:
-        """Prepare information about the traces for training.
+        """Prepare information about the traces for execution.
 
         Add default traces into the traces_in_use list, also prints a warning if no model saver trace is detected.
 
@@ -141,8 +140,8 @@ class Estimator:
         # Look for any monitor names which should be automagically added.
         trace_outputs = set()
         extra_monitor_keys = set()
-        for trace in sort_traces(get_current_items(self.traces_in_use, run_modes=run_modes)):
-            trace_outputs.update(trace.outputs)
+        for trace in sort_traces(get_current_items(self.traces_in_use, run_modes=run_modes), ds_ids=[]):
+            trace_outputs.update(trace.get_outputs(ds_ids=[]))
             extra_monitor_keys.update(trace.fe_monitor_names - trace_outputs)
         # Add the essential traces
         if "train" in run_modes:
@@ -161,13 +160,15 @@ class Estimator:
         for trace in get_current_items(self.traces_in_use, run_modes=run_modes):
             trace.system = self.system
 
-    def test(self, summary: Optional[str] = None) -> Optional[Summary]:
+    def test(self, summary: Optional[str] = None, eager: bool = False) -> Optional[Summary]:
         """Run the pipeline / network in test mode for one epoch.
 
         Args:
             summary: A name for the experiment. If provided, the log history will be recorded in-memory and returned as
                 a summary object at the end of training. If None, the default value will be whatever `summary` name was
                 most recently provided to this Estimator's .fit() or .test() methods.
+            eager: Whether to run the training in eager mode. This is only related to TensorFlow training because
+                PyTorch by nature is always in eager mode.
 
         Returns:
             A summary object containing the training history for this session iff the `summary` name is not None (after
@@ -175,65 +176,67 @@ class Estimator:
         """
         self.system.reset_for_test(summary)
         self._prepare_traces(run_modes={"test"})
-        self._start(run_modes={"test"})
+        self._start(run_modes={"test"}, eager=eager)
         return self.system.summary or None
 
-    def _warmup(self, warmup: Union[bool, str]) -> None:
+    def _warmup(self, eager: bool = True) -> None:
         """Perform a test run of each pipeline and network signature epoch to make sure that training won't fail later.
 
         Traces are not executed in the warmup since they are likely to contain state variables which could become
         corrupted by running extra steps.
 
         Args:
-            warmup: Warmup arg specified by estimator.fit.
+            eager: Whether to run the training in eager mode. This is only related to TensorFlow training because
+                PyTorch by nature is always in eager mode.
         """
         all_traces = get_current_items(self.traces_in_use, run_modes={"train", "eval"})
-        sort_traces(all_traces)  # This ensures that the traces can sort properly for on_begin and on_end
+        sort_traces(all_traces, ds_ids=[])  # This ensures that the traces can sort properly for on_begin and on_end
         monitor_names = self.monitor_names
-        signature_epochs = {}
         for mode in self.pipeline.get_modes() - {"test"}:
             scheduled_items = self.pipeline.get_scheduled_items(mode) + self.network.get_scheduled_items(
                 mode) + self.get_scheduled_items(mode)
-            signature_epochs[mode] = get_signature_epochs(scheduled_items, self.system.total_epochs, mode=mode)
-        if max([len(x) for x in signature_epochs.values()]) < 2 and warmup != "debug":
-            return
-        for mode, signature_epochs_mode in signature_epochs.items():
+            signature_epochs = get_signature_epochs(scheduled_items, self.system.total_epochs, mode=mode)
             epochs_with_data = self.pipeline.get_epochs_with_data(total_epochs=self.system.total_epochs, mode=mode)
-            for epoch in signature_epochs_mode:
+            for epoch in signature_epochs:
                 if epoch not in epochs_with_data:
                     continue
-                network_output_keys = self.network.get_all_output_keys(mode, epoch)
-                network_input_keys = self.network.get_effective_input_keys(mode, epoch)
-                trace_input_keys = set()
-                trace_output_keys = {"*"}
-                traces = get_current_items(self.traces_in_use, run_modes=mode, epoch=epoch)
-                for idx, trace in enumerate(traces):
-                    if idx > 0:  # ignore TrainEssential and EvalEssential's inputs for unmet requirement checking
-                        trace_input_keys.update(trace.inputs)
-                    trace_output_keys.update(trace.outputs)
-                # key checking
-                loader = self._configure_loader(
-                    self.pipeline.get_loader(mode,
-                                             epoch,
-                                             output_keys=trace_input_keys - network_output_keys | network_input_keys))
-                with Suppressor():
-                    if isinstance(loader, tf.data.Dataset):
-                        batch = list(loader.take(1))[0]
-                    else:
-                        batch = next(iter(loader))
-                batch = self._configure_tensor(loader, batch)
-                assert isinstance(batch, dict), "please make sure data output format is dictionary"
-                pipeline_output_keys = to_set(batch.keys())
+                ds_ids = self.pipeline.get_ds_ids(epoch, mode)
+                for ds_id in ds_ids:
+                    network_output_keys = self.network.get_all_output_keys(mode, epoch, ds_id=ds_id)
+                    network_input_keys = self.network.get_effective_input_keys(mode, epoch, ds_id=ds_id)
+                    trace_input_keys = set()
+                    trace_output_keys = {"*"}
+                    traces = get_current_items(self.traces_in_use, run_modes=mode, epoch=epoch, ds_id=ds_id)
+                    for idx, trace in enumerate(traces):
+                        if idx > 0:  # ignore TrainEssential and EvalEssential's inputs for unmet requirement checking
+                            trace_input_keys.update(trace.inputs)
+                        trace_output_keys.update(trace.get_outputs(ds_ids=ds_ids))
+                    # key checking
+                    with self.pipeline(mode=mode,
+                                       epoch=epoch,
+                                       ds_id=ds_id,
+                                       output_keys=trace_input_keys - network_output_keys
+                                       | network_input_keys) as loader:
+                        loader = self._configure_loader(loader)
+                        with Suppressor():
+                            if isinstance(loader, tf.data.Dataset):
+                                batch = list(loader.take(1))[0]
+                            else:
+                                batch = next(iter(loader))
+                        batch = self._configure_tensor(loader, batch)
+                    assert isinstance(batch, dict), "please make sure data output format is dictionary"
+                    pipeline_output_keys = to_set(batch.keys())
 
-                monitor_names = monitor_names - (pipeline_output_keys | network_output_keys)
-                unmet_requirements = trace_input_keys - (pipeline_output_keys | network_output_keys | trace_output_keys)
-                assert not unmet_requirements, \
-                    "found missing key(s) during epoch {} mode {}: {}".format(epoch, mode, unmet_requirements)
-                sort_traces(traces, available_outputs=pipeline_output_keys | network_output_keys)
-                trace_input_keys.update(traces[0].inputs)
-                self.network.load_epoch(mode, epoch, output_keys=trace_input_keys, warmup=warmup)
-                self.network.run_step(batch)
-                self.network.unload_epoch()
+                    monitor_names = monitor_names - (pipeline_output_keys | network_output_keys)
+                    unmet_requirements = trace_input_keys - (pipeline_output_keys | network_output_keys
+                                                             | trace_output_keys)
+                    assert not unmet_requirements, \
+                        "found missing key(s) during epoch {} mode {} ds_id {}: {}".format(epoch, mode, ds_id, unmet_requirements)
+                    sort_traces(traces, ds_ids=ds_ids, available_outputs=pipeline_output_keys | network_output_keys)
+                    trace_input_keys.update(traces[0].inputs)
+                    self.network.load_epoch(mode, epoch, ds_id, output_keys=trace_input_keys, warmup=True, eager=eager)
+                    self.network.run_step(batch)
+                    self.network.unload_epoch()
         assert not monitor_names, "found missing key(s): {}".format(monitor_names)
 
     def get_scheduled_items(self, mode: str) -> List[Any]:
@@ -247,7 +250,7 @@ class Estimator:
         """
         return self.traces_in_use
 
-    def _start(self, run_modes: Set[str]) -> None:
+    def _start(self, run_modes: Set[str], eager: bool) -> None:
         """The outer training loop.
 
         This method invokes the trace on_begin method, runs the necessary 'train' and 'eval' epochs, and then invokes
@@ -255,71 +258,101 @@ class Estimator:
 
         Args:
             run_modes: The current execution modes.
+            eager: Whether to run the training in eager mode. This is only related to TensorFlow training because
+                PyTorch by nature is always in eager mode.
         """
-        all_traces = sort_traces(get_current_items(self.traces_in_use, run_modes=run_modes))
-        with NonContext() if fe.fe_history_path is False else HistoryRecorder(
-                self.system, self.filepath, db_path=fe.fe_history_path):
-            try:
-                self._run_traces_on_begin(traces=all_traces)
-                if "train" in run_modes or "eval" in run_modes:
-                    # If the training is re-starting from a restore wizard, it should re-run the last eval epoch
-                    if self.system.epoch_idx > 0 and "eval" in self.pipeline.get_modes(epoch=self.system.epoch_idx):
+        all_traces = sort_traces(get_current_items(self.traces_in_use, run_modes=run_modes), ds_ids=[])
+        try:
+            self._run_traces_on_begin(traces=all_traces)
+            if "train" in run_modes or "eval" in run_modes:
+                # If the training is re-starting from a restore wizard, it should re-run the last eval epoch
+                if self.system.epoch_idx > 0 and "eval" in self.pipeline.get_modes(epoch=self.system.epoch_idx):
+                    self.system.mode = "eval"
+                    self._run_epoch(eager=eager)
+                for self.system.epoch_idx in range(self.system.epoch_idx + 1, self.system.total_epochs + 1):
+                    if "train" in self.pipeline.get_modes(epoch=self.system.epoch_idx):
+                        self.system.mode = "train"
+                        self._run_epoch(eager=eager)
+                    if "eval" in self.pipeline.get_modes(epoch=self.system.epoch_idx):
                         self.system.mode = "eval"
-                        self._run_epoch()
-                    for self.system.epoch_idx in range(self.system.epoch_idx + 1, self.system.total_epochs + 1):
-                        if "train" in self.pipeline.get_modes(epoch=self.system.epoch_idx):
-                            self.system.mode = "train"
-                            self._run_epoch()
-                        if "eval" in self.pipeline.get_modes(epoch=self.system.epoch_idx):
-                            self.system.mode = "eval"
-                            self._run_epoch()
-                else:
-                    self._run_epoch()
-            except EarlyStop:
-                pass  # On early stopping we still want to run the final traces and return results
-            self._run_traces_on_end(traces=all_traces)
+                        self._run_epoch(eager=eager)
+            else:
+                self._run_epoch(eager=eager)
+        except EarlyStop:
+            pass  # On early stopping we still want to run the final traces and return results
+        self._run_traces_on_end(traces=all_traces)
 
-    def _run_epoch(self) -> None:
+    def _run_epoch(self, eager: bool) -> None:
         """A method to perform an epoch of activity.
 
         This method requires that the current mode and epoch already be specified within the self.system object.
+
+        Args:
+            eager: Whether to run the training in eager mode. This is only related to TensorFlow training because
+                PyTorch by nature is always in eager mode.
         """
-        traces = get_current_items(self.traces_in_use, run_modes=self.system.mode, epoch=self.system.epoch_idx)
-        trace_input_keys = set()
-        for trace in traces:
-            trace_input_keys.update(trace.inputs)
-        network_input_keys = self.network.get_effective_input_keys(self.system.mode, self.system.epoch_idx)
-        network_output_keys = self.network.get_all_output_keys(self.system.mode, self.system.epoch_idx)
-        loader = self._configure_loader(
-            self.pipeline.get_loader(self.system.mode,
-                                     self.system.epoch_idx,
-                                     output_keys=trace_input_keys - network_output_keys | network_input_keys))
-        iterator = iter(loader)
-        self.network.load_epoch(mode=self.system.mode, epoch=self.system.epoch_idx, output_keys=trace_input_keys)
+        ds_ids = self.pipeline.get_ds_ids(self.system.epoch_idx, self.system.mode)
+        epoch_traces = sort_traces(
+            get_current_items(self.traces_in_use, run_modes=self.system.mode, epoch=self.system.epoch_idx),
+            ds_ids=ds_ids)
+        self._run_traces_on_epoch_begin(traces=epoch_traces)
         self.system.batch_idx = None
-        with Suppressor():
-            batch = next(iterator)
-        traces = sort_traces(traces, available_outputs=to_set(batch.keys()) | network_output_keys)
-        self._run_traces_on_epoch_begin(traces=traces)
-        while True:
-            try:
-                if self.system.mode == "train":
-                    self.system.update_global_step()
-                self.system.update_batch_idx()
-                batch = self._configure_tensor(loader, batch)
-                self._run_traces_on_batch_begin(batch, traces=traces)
-                batch, prediction = self.network.run_step(batch)
-                self._run_traces_on_batch_end(batch, prediction, traces=traces)
-                if isinstance(loader, DataLoader) and (
-                    (self.system.batch_idx == self.system.max_train_steps_per_epoch and self.system.mode == "train") or
-                    (self.system.batch_idx == self.system.max_eval_steps_per_epoch and self.system.mode == "eval")):
-                    raise StopIteration
+        end_epoch_data = Data()  # We will aggregate data over on_ds_end and put it into on_epoch_end for printing
+        # run for each dataset
+        for self.system.ds_id in ds_ids:
+            ds_traces = get_current_items(self.traces_in_use,
+                                          run_modes=self.system.mode,
+                                          epoch=self.system.epoch_idx,
+                                          ds_id=self.system.ds_id)
+            trace_input_keys = set()
+            for ds_trace in ds_traces:
+                trace_input_keys.update(ds_trace.inputs)
+            network_input_keys = self.network.get_effective_input_keys(mode=self.system.mode,
+                                                                       epoch=self.system.epoch_idx,
+                                                                       ds_id=self.system.ds_id)
+            network_output_keys = self.network.get_all_output_keys(mode=self.system.mode,
+                                                                   epoch=self.system.epoch_idx,
+                                                                   ds_id=self.system.ds_id)
+            self.network.load_epoch(mode=self.system.mode,
+                                    epoch=self.system.epoch_idx,
+                                    ds_id=self.system.ds_id,
+                                    output_keys=trace_input_keys,
+                                    eager=eager)
+            with self.pipeline(mode=self.system.mode,
+                               epoch=self.system.epoch_idx,
+                               ds_id=self.system.ds_id,
+                               output_keys=trace_input_keys - network_output_keys | network_input_keys) as loader:
+                loader = self._configure_loader(loader)
+                iterator = iter(loader)
                 with Suppressor():
                     batch = next(iterator)
-            except StopIteration:
-                break
-        self._run_traces_on_epoch_end(traces=traces)
-        self.network.unload_epoch()
+                ds_traces = sort_traces(ds_traces,
+                                        available_outputs=to_set(batch.keys()) | network_output_keys,
+                                        ds_ids=ds_ids)
+                per_ds_traces = [trace for trace in ds_traces if isinstance(trace, PerDSTrace)]
+                self._run_traces_on_ds_begin(traces=per_ds_traces)
+                while True:
+                    try:
+                        if self.system.mode == "train":
+                            self.system.update_global_step()
+                        self.system.update_batch_idx()
+                        batch = self._configure_tensor(loader, batch)
+                        self._run_traces_on_batch_begin(batch, traces=ds_traces)
+                        batch, prediction = self.network.run_step(batch)
+                        self._run_traces_on_batch_end(batch, prediction, traces=ds_traces)
+                        if isinstance(loader,
+                                      DataLoader) and ((self.system.batch_idx == self.system.max_train_steps_per_epoch
+                                                        and self.system.mode == "train") or
+                                                       (self.system.batch_idx == self.system.max_eval_steps_per_epoch
+                                                        and self.system.mode == "eval")):
+                            raise StopIteration
+                        with Suppressor():
+                            batch = next(iterator)
+                    except StopIteration:
+                        break
+                self._run_traces_on_ds_end(traces=per_ds_traces, data=end_epoch_data)
+            self.network.unload_epoch()
+        self._run_traces_on_epoch_end(traces=epoch_traces, data=end_epoch_data)
 
     def _configure_loader(self, loader: Union[DataLoader, tf.data.Dataset]) -> Union[DataLoader, tf.data.Dataset]:
         """A method to configure a given dataloader for use with this Estimator's Network.
@@ -336,7 +369,7 @@ class Estimator:
         new_loader = loader
         if isinstance(new_loader, DataLoader) and isinstance(self.network, TFNetwork):
             add_batch = True
-            if hasattr(loader.dataset, "dataset") and isinstance(loader.dataset.dataset, BatchDataset):
+            if isinstance(loader.dataset, OpDataset) and loader.dataset.dataset.fe_batch:
                 add_batch = False
             batch = to_tensor(loader.dataset[0], target_type="tf")
             data_type = to_type(batch)
@@ -400,6 +433,17 @@ class Estimator:
             trace.on_epoch_begin(data)
         self._check_early_exit()
 
+    def _run_traces_on_ds_begin(self, traces: Iterable[PerDSTrace]) -> None:
+        """Invoke the on_ds_begin methods of given traces.
+
+        Args:
+            traces: List of traces.
+        """
+        data = Data()
+        for trace in traces:
+            trace.on_ds_begin(data)
+        self._check_early_exit()
+
     def _run_traces_on_batch_begin(self, batch: Dict[str, Any], traces: Iterable[Trace]) -> None:
         """Invoke the on_batch_begin methods of given traces.
 
@@ -426,13 +470,24 @@ class Estimator:
             trace.on_batch_end(data)
         self._check_early_exit()
 
-    def _run_traces_on_epoch_end(self, traces: Iterable[Trace]) -> None:
+    def _run_traces_on_ds_end(self, traces: Iterable[PerDSTrace], data: Data) -> None:
+        """Invoke the on_ds_begin methods of given traces.
+
+        Args:
+            traces: List of traces.
+            data: Data into which to record results.
+        """
+        for trace in traces:
+            trace.on_ds_end(data)
+        self._check_early_exit()
+
+    def _run_traces_on_epoch_end(self, traces: Iterable[Trace], data: Data) -> None:
         """Invoke the on_epoch_end methods of of given traces.
 
         Args:
             traces: List of traces.
+            data: Data into which to record results.
         """
-        data = Data()
         for trace in traces:
             trace.on_epoch_end(data)
         self._check_early_exit()
@@ -472,16 +527,13 @@ class EarlyStop(Exception):
     """
 
 
-def enable_deterministic(seed: int) -> None:
-    """Invoke to set random seed for deterministic training.
-
-    The determinism only works for tensorflow >= 2.1 and pytorch >= 1.14, and some model layers don't support.
+def enable_deterministic(seed):
+    """Invoke to set random seed for deterministic training. The determinism only works for tensorflow >= 2.1 and
+    pytorch >= 1.14, and some model layers don't support.
 
     Known failing layers:
     * tf.keras.layers.UpSampling2D
 
-    Args:
-        seed: The random seed to use for training.
     """
     fe.fe_deterministic_seed = seed
     os.environ['PYTHONHASHSEED'] = str(seed)
@@ -490,16 +542,3 @@ def enable_deterministic(seed: int) -> None:
     np.random.seed(seed)
     tf.random.set_seed(seed)
     torch.manual_seed(seed)
-
-
-def record_history(path: Union[bool, str]) -> None:
-    """Change the default location for history tracking.
-
-    Args:
-        path: The path to save experiment histories. Pass True to use the default location of
-            ~/fastestimator_data/history.db. Pass False to disable history tracking.
-    """
-    if path in (None, True):
-        fe.fe_history_path = None
-    else:
-        fe.fe_history_path = path
