@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-from typing import List, Optional, Union
+from typing import Iterable, List, Optional, Union
 
 from albumentations import BboxParams, KeypointParams
 from albumentations.augmentations.transforms import CropNonEmptyMaskIfExists as CropNonEmptyMaskIfExistsAlb
@@ -29,6 +29,8 @@ class CropNonEmptyMaskIfExists(MultiVariateAlbumentation):
         mode: What mode(s) to execute this Op in. For example, "train", "eval", "test", or "infer". To execute
             regardless of mode, pass None. To execute in all modes except for a particular one, you can pass an argument
             like "!infer" or "!train".
+        ds_id: What dataset id(s) to execute this Op in. To execute regardless of ds_id, pass None. To execute in all
+            ds_ids except for a particular one, you can pass an argument like "!ds1".
         image_in: The key of an image to be modified.
         mask_in: The key of a mask to be modified (with the same random factors as the image).
         masks_in: The key of masks to be modified (with the same random factors as the image).
@@ -43,7 +45,7 @@ class CropNonEmptyMaskIfExists(MultiVariateAlbumentation):
         keypoint_params: Parameters defining the type of keypoints ('xy', 'yx', 'xya', 'xys', 'xyas', 'xysa').
         height: Vertical size of crop in pixels.
         width: Horizontal size of crop in pixels.
-        ignore_values: Values to ignore in mask, `0` values are always ignored (e.g. if background value is 5 set 
+        ignore_values: Values to ignore in mask, `0` values are always ignored (e.g. if background value is 5 set
             `ignore_values=[5]` to ignore).
         ignore_channels: Channels to ignore in mask (e.g. if background is a first channel set `ignore_channels=[0]` to
             ignore).
@@ -56,7 +58,8 @@ class CropNonEmptyMaskIfExists(MultiVariateAlbumentation):
                  width: int,
                  ignore_values: Optional[List[int]] = None,
                  ignore_channels: Optional[List[int]] = None,
-                 mode: Optional[str] = None,
+                 mode: Union[None, str, Iterable[str]] = None,
+                 ds_id: Union[None, str, Iterable[str]] = None,
                  image_in: Optional[str] = None,
                  mask_in: Optional[str] = None,
                  masks_in: Optional[str] = None,
@@ -87,4 +90,5 @@ class CropNonEmptyMaskIfExists(MultiVariateAlbumentation):
             keypoints_out=keypoints_out,
             bbox_params=bbox_params,
             keypoint_params=keypoint_params,
-            mode=mode)
+            mode=mode,
+            ds_id=ds_id)
