@@ -30,6 +30,8 @@ class ISONoise(ImageOnlyAlbumentation):
         mode: What mode(s) to execute this Op in. For example, "train", "eval", "test", or "infer". To execute
             regardless of mode, pass None. To execute in all modes except for a particular one, you can pass an argument
             like "!infer" or "!train".
+        ds_id: What dataset id(s) to execute this Op in. To execute regardless of ds_id, pass None. To execute in all
+            ds_ids except for a particular one, you can pass an argument like "!ds1".
         color_shift: Variance range for color hue change. Measured as a fraction of 360 degree Hue angle in the HLS
             colorspace.
         intensity: Multiplicative factor that controls the strength of color and luminace noise.
@@ -41,9 +43,11 @@ class ISONoise(ImageOnlyAlbumentation):
                  inputs: Union[str, Iterable[str]],
                  outputs: Union[str, Iterable[str]],
                  mode: Union[None, str, Iterable[str]] = None,
+                 ds_id: Union[None, str, Iterable[str]] = None,
                  color_shift: Tuple[float, float] = (0.01, 0.05),
                  intensity: Tuple[float, float] = (0.1, 0.5)):
         super().__init__(ISONoiseAlb(color_shift=color_shift, intensity=intensity, always_apply=True),
                          inputs=inputs,
                          outputs=outputs,
-                         mode=mode)
+                         mode=mode,
+                         ds_id=ds_id)
