@@ -30,6 +30,8 @@ class RandomGamma(ImageOnlyAlbumentation):
         mode: What mode(s) to execute this Op in. For example, "train", "eval", "test", or "infer". To execute
             regardless of mode, pass None. To execute in all modes except for a particular one, you can pass an argument
             like "!infer" or "!train".
+        ds_id: What dataset id(s) to execute this Op in. To execute regardless of ds_id, pass None. To execute in all
+            ds_ids except for a particular one, you can pass an argument like "!ds1".
         gamma_limit: If gamma_limit is a single float value, the range will be (-gamma_limit, gamma_limit).
         eps: A numerical stability constant to avoid division by zero.
 
@@ -40,9 +42,11 @@ class RandomGamma(ImageOnlyAlbumentation):
                  inputs: Union[str, Iterable[str]],
                  outputs: Union[str, Iterable[str]],
                  mode: Union[None, str, Iterable[str]] = None,
+                 ds_id: Union[None, str, Iterable[str]] = None,
                  gamma_limit: Union[float, Tuple[float, float]] = (80, 120),
                  eps: float = 1e-7):
         super().__init__(RandomGammaAlb(gamma_limit=gamma_limit, eps=eps, always_apply=True),
                          inputs=inputs,
                          outputs=outputs,
-                         mode=mode)
+                         mode=mode,
+                         ds_id=ds_id)
