@@ -12,6 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-from fastestimator.schedule.lr_shedule import cosine_decay
+from fastestimator.schedule.lr_shedule import ARC, cosine_decay
 from fastestimator.schedule.schedule import EpochScheduler, RepeatScheduler, Scheduler, get_current_items, \
     get_signature_epochs
