@@ -15,7 +15,6 @@
 import datetime
 import json
 import os
-import uuid
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, TypeVar, Union
 
 import dill as pickle  # Need to use dill since tf.Variable is a weakref object on multi-gpu machines
@@ -55,7 +54,7 @@ class System:
 
     Attributes:
         mode: What is the current execution mode of the estimator ('train', 'eval', 'test'), None if warmup.
-        exp_id: A unique identifier for current training experiment.
+        ds_id: The current dataset id, None if there is only one dataset in each mode.
         global_step: How many training steps have elapsed.
         num_devices: How many GPUs are available for training.
         log_steps: Log every n steps (0 to disable train logging, None to disable all logging).
@@ -74,7 +73,7 @@ class System:
     """
 
     mode: Optional[str]
-    exp_id: int
+    ds_id: Optional[str]
     global_step: Optional[int]
     num_devices: int
     log_steps: Optional[int]
@@ -96,6 +95,7 @@ class System:
                  pipeline: Pipeline,
                  traces: List[Union['Trace', Scheduler['Trace']]],
                  mode: Optional[str] = None,
+                 ds_id: Optional[str] = None,
                  num_devices: int = torch.cuda.device_count(),
                  log_steps: Optional[int] = None,
                  total_epochs: int = 0,
@@ -107,6 +107,7 @@ class System:
         self.pipeline = pipeline
         self.traces = traces
         self.mode = mode
+        self.ds_id = ds_id
         self.num_devices = num_devices
         self.log_steps = log_steps
         self.total_epochs = total_epochs
@@ -124,8 +125,6 @@ class System:
         """
         self.global_step = None
         self.epoch_idx = 0
-        # Get a 64 bit random id related to current time
-        self.exp_id = int.from_bytes(uuid.uuid1().bytes, byteorder='big', signed=True) >> 64
 
     def update_global_step(self) -> None:
         """Increment the current `global_step`.
@@ -152,6 +151,7 @@ class System:
         """
         self.experiment_time = datetime.datetime.now().strftime("%Y%m%d-%H%M%S")
         self.mode = "train"
+        self.ds_id = None
         self._initialize_state()
         self.batch_idx = None
         self.stop_training = False
@@ -166,6 +166,7 @@ class System:
         """
         self.experiment_time = self.experiment_time or datetime.datetime.now().strftime("%Y%m%d-%H%M%S")
         self.mode = "test"
+        self.ds_id = None
         if not self.stop_training:
             self.epoch_idx = self.total_epochs
         self.stop_training = False
@@ -221,9 +222,12 @@ class System:
             'tops': [op.__getstate__() if hasattr(op, '__getstate__') else {} for op in self.network.ops],
             'pops': [op.__getstate__() if hasattr(op, '__getstate__') else {} for op in self.network.postprocessing],
             'nops': [op.__getstate__() if hasattr(op, '__getstate__') else {} for op in self.pipeline.ops],
-            'ds':
-            {key: value.__getstate__()
-             for key, value in self.pipeline.data.items() if hasattr(value, '__getstate__')}
+            'ds': {
+                mode: {key: value.__getstate__()
+                       for key, value in ds.items() if hasattr(value, '__getstate__')}
+                for mode,
+                ds in self.pipeline.data.items()
+            }
         }
         with open(os.path.join(save_dir, 'objects.pkl'), 'wb') as file:
             pickle.dump(objects, file)
@@ -340,6 +344,8 @@ class System:
                 obj.__setstate__(state)
             elif hasattr(obj, '__dict__'):
                 obj.__dict__.update(state)
+            elif isinstance(obj, dict):
+                [System._load_dict(states, k, obj) for k in states]
             else:
                 # Might be a None or something else that can't be updated
                 pass
