@@ -1,17 +1,3 @@
-# Copyright 2021 The FastEstimator Authors. All Rights Reserved.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-# ==============================================================================
 from collections import ChainMap
 from typing import Any, Dict
 
@@ -112,6 +98,16 @@ def one_layer_tf_model() -> tf.keras.Model:
     return model
 
 
+def multi_layer_tf_model() -> tf.keras.Model:
+    inp = tf.keras.layers.Input([4])
+    x = tf.keras.layers.Dense(units=2, use_bias=False, name='fc1')(inp)
+    x = tf.keras.layers.Dense(units=1, use_bias=False, name='fc2')(x)
+    model = tf.keras.models.Model(inputs=inp, outputs=x)
+    model.layers[1].set_weights([np.array([[1.0, 2.0], [2.0, 3.0], [3.0, 4.0], [4.0, 6.0]])])
+    model.layers[2].set_weights([np.array([[1.0], [2.0]])])
+    return model
+
+
 class OneLayerTorchModel(torch.nn.Module):
     """Torch Model with one dense layer without activation function.
     * Model input shape: (3,)
@@ -277,8 +273,10 @@ class TraceRun:
         self.data_on_batch_begin = None
         self.data_on_batch_end = None
 
-
     def run_trace(self) -> None:
+        system = sample_system_object()
+        self.trace.system = system
+
         self.data_on_begin = Data()
         self.trace.on_begin(self.data_on_begin)
 
