@@ -271,11 +271,6 @@ class Suppressor(object):
         """
         pass
 
-    def flush(self) -> None:
-        """A function to empty the current print buffer. No-op in this case.
-        """
-        pass
-
 
 class LogSplicer:
     """A class to send stdout information into a file before passing it along to the normal stdout.
@@ -483,6 +478,16 @@ def get_shape(obj: Any) -> List[Optional[int]]:
     return result
 
 
+def check_io_names(names: List[Optional[str]]) -> List[Optional[str]]:
+    forbidden_chars = {":", ";"}
+    for name in names:
+        assert not any(char in name for char in forbidden_chars), \
+            "inputs/outputs name cannot contain characters like ':', ';', found {}".format(name)
+        assert len(name) > 0, "inputs/outputs cannot be an empty string"
+        assert len(name.split('|')) < 3, f"inputs/outputs cannot contain more than one '|' character, found {name}"
+    return names
+
+
 def parse_modes(modes: Set[str]) -> Set[str]:
     """A function to determine which modes to run on based on a set of modes potentially containing blacklist values.
 
@@ -514,6 +519,38 @@ def parse_modes(modes: Set[str]) -> Set[str]:
     return modes
 
 
+def check_ds_id(ds_ids: Set[str]) -> Set[str]:
+    """A function to check whether ds_ids inputs are correct inputs.
+
+    ds_ids should either be defined through whitelist, like {"ds1", "ds2"} or blacklist, like {"!ds1", "!ds2"}.
+
+    ```python
+    m = fe.util.parse_ds_id({"ds1"})  # {"ds1"}
+    m = fe.util.parse_ds_id({"!ds1"})  # {"!ds1"}
+    m = fe.util.parse_ds_id({"ds1", "ds2"})  # {"ds1", "ds2"}
+    m = fe.util.parse_ds_id({"!ds1", "!ds2"})  # {"!ds1", "!ds2"}
+    m = fe.util.parse_ds_id({"!ds1", "ds2"})  # Raises Assertion
+    ```
+
+    Args:
+        ds_ids: The desired ds_id to run on (possibly containing blacklisted ds_ids).
+
+    Returns:
+        The ds_ids to run or to avoid.
+
+    Raises:
+        AssertionError: if blacklisted modes and whitelisted modes are mixed.
+    """
+    negation = set([ds_id.startswith("!") for ds_id in ds_ids])
+    assert len(negation) < 2, "cannot mix !ds_id with ds_id, found {}".format(ds_ids)
+    forbidden_ds_id_chars = {":", ";", "|"}
+    for ds_id in ds_ids:
+        assert isinstance(ds_id, str) and len(ds_id) > 0, "dataset id must be a string, found {}".format(ds_id)
+        assert not any(char in ds_id for char in forbidden_ds_id_chars), \
+            "dataset id should not contain forbidden characters like ':', ';', '|', found {}".format(ds_id)
+    return ds_ids
+
+
 def pad_batch(batch: List[MutableMapping[str, np.ndarray]], pad_value: Union[float, int]) -> None:
     """A function to pad a batch of data in-place by appending to the ends of the tensors. Tensor type needs to be
     numpy array otherwise would get ignored. (tf.Tensor and torch.Tensor will cause error)
