@@ -237,7 +237,6 @@ class TestUpdateOp(unittest.TestCase):
                         if (mixed_precision and gradient) or (torch.cuda.device_count() > 1 and merge_grad > 1):
                             with self.assertRaises(ValueError):
                                 run_test(mixed_precision, merge_grad, gradient)
-
                         else:
                             run_test(mixed_precision, merge_grad, gradient)
 
@@ -418,10 +417,8 @@ class TestUpdateOp(unittest.TestCase):
                                    batch_size=4,
                                    ops=[ExpandDims(inputs="x", outputs="x", axis=0), Minmax(inputs="x", outputs="x")])
 
-            optimizer_fn = RepeatScheduler([
-                lambda x: torch.optim.SGD(params=x, lr=lr),
-                lambda x: torch.optim.SGD(params=x, lr=lr2)
-            ])
+            optimizer_fn = RepeatScheduler(
+                [lambda x: torch.optim.SGD(params=x, lr=lr), lambda x: torch.optim.SGD(params=x, lr=lr2)])
 
             model = fe.build(model_fn=LeNet_torch, optimizer_fn=optimizer_fn, mixed_precision=mixed_precision)
             network = fe.Network(ops=[
