@@ -87,7 +87,7 @@ class TestRepeatScheduler(unittest.TestCase):
 
         # make some changes
         new_var = 2
-        system.pipeline.data["train"].get_current_value(1).var = new_var
+        system.pipeline.data["train"][None].get_current_value(1).var = new_var
 
         # save the state
         save_path = tempfile.mkdtemp()
@@ -97,7 +97,7 @@ class TestRepeatScheduler(unittest.TestCase):
         system = instantiate_system()
         system.load_state(save_path)
 
-        loaded_var = system.pipeline.data["train"].get_current_value(1).var
+        loaded_var = system.pipeline.data["train"][None].get_current_value(1).var
         self.assertEqual(loaded_var, new_var)
 
     def test_save_and_load_state_with_ds_scheduler_torch(self):
@@ -121,7 +121,7 @@ class TestRepeatScheduler(unittest.TestCase):
 
         # make some changes
         new_var = 2
-        system.pipeline.data["train"].get_current_value(1).var = new_var
+        system.pipeline.data["train"][None].get_current_value(1).var = new_var
 
         # save the state
         save_path = tempfile.mkdtemp()
@@ -131,7 +131,7 @@ class TestRepeatScheduler(unittest.TestCase):
         system = instantiate_system()
         system.load_state(save_path)
 
-        loaded_var = system.pipeline.data["train"].get_current_value(1).var
+        loaded_var = system.pipeline.data["train"][None].get_current_value(1).var
         self.assertEqual(loaded_var, new_var)
 
     def test_save_and_load_state_with_top_scheduler_tf(self):
@@ -311,9 +311,9 @@ class TestRepeatScheduler(unittest.TestCase):
 
         # make some changes
         new_var1 = 4
-        system.pipeline.data["train"].get_current_value(1).var = new_var1
+        system.pipeline.data["train"][None].get_current_value(1).var = new_var1
         new_var2 = 99
-        system.pipeline.data["train"].get_current_value(2).var = new_var2
+        system.pipeline.data["train"][None].get_current_value(2).var = new_var2
 
         # save the state
         save_path = tempfile.mkdtemp()
@@ -324,16 +324,16 @@ class TestRepeatScheduler(unittest.TestCase):
         system.load_state(save_path)
 
         with self.subTest('Check that repeat list is still populated'):
-            self.assertEqual(2, len(system.pipeline.data['train'].repeat_list))
+            self.assertEqual(2, len(system.pipeline.data["train"][None].repeat_list))
         with self.subTest('Check that classes are still intact'):
-            self.assertTrue(isinstance(system.pipeline.data['train'].get_current_value(1), TestNonTraceableDataset))
-            self.assertTrue(isinstance(system.pipeline.data['train'].get_current_value(2), TestNonTraceableDataset))
+            self.assertTrue(isinstance(system.pipeline.data["train"][None].get_current_value(1), TestNonTraceableDataset))
+            self.assertTrue(isinstance(system.pipeline.data["train"][None].get_current_value(2), TestNonTraceableDataset))
         with self.subTest('Check that the 1st repeat list entry was not restored'):
             # Since the dataset is not traceable changes shouldn't get restored
-            loaded_var = system.pipeline.data["train"].get_current_value(1).var
+            loaded_var = system.pipeline.data["train"][None].get_current_value(1).var
             self.assertEqual(loaded_var, 3)
         with self.subTest('Check that the 2nd repeat list entry was not restored'):
-            loaded_var = system.pipeline.data["train"].get_current_value(2).var
+            loaded_var = system.pipeline.data["train"][None].get_current_value(2).var
             self.assertEqual(loaded_var, 7)
 
     def test_save_and_load_state_with_hybrid_entries(self):
@@ -354,9 +354,9 @@ class TestRepeatScheduler(unittest.TestCase):
 
         # make some changes
         new_var1 = 4
-        system.pipeline.data["train"].get_current_value(1).var = new_var1
+        system.pipeline.data["train"][None].get_current_value(1).var = new_var1
         new_var2 = 99
-        system.pipeline.data["train"].get_current_value(2).var = new_var2
+        system.pipeline.data["train"][None].get_current_value(2).var = new_var2
 
         # save the state
         save_path = tempfile.mkdtemp()
@@ -367,15 +367,15 @@ class TestRepeatScheduler(unittest.TestCase):
         system.load_state(save_path)
 
         with self.subTest('Check that repeat list is still populated'):
-            self.assertEqual(3, len(system.pipeline.data['train'].repeat_list))
+            self.assertEqual(3, len(system.pipeline.data["train"][None].repeat_list))
         with self.subTest('Check that classes are still intact'):
-            self.assertTrue(isinstance(system.pipeline.data['train'].get_current_value(1), TestNonTraceableDataset))
-            self.assertTrue(isinstance(system.pipeline.data['train'].get_current_value(2), TestDataset))
-            self.assertTrue(system.pipeline.data['train'].get_current_value(3) is None)
+            self.assertTrue(isinstance(system.pipeline.data["train"][None].get_current_value(1), TestNonTraceableDataset))
+            self.assertTrue(isinstance(system.pipeline.data["train"][None].get_current_value(2), TestDataset))
+            self.assertTrue(system.pipeline.data["train"][None].get_current_value(3) is None)
         with self.subTest('Check that the 1st repeat list entry was not restored'):
             # Since the dataset is not traceable changes shouldn't get restored
-            loaded_var = system.pipeline.data["train"].get_current_value(1).var
+            loaded_var = system.pipeline.data["train"][None].get_current_value(1).var
             self.assertEqual(loaded_var, 3)
         with self.subTest('Check that the 2nd repeat list entry was restored'):
-            loaded_var = system.pipeline.data["train"].get_current_value(2).var
+            loaded_var = system.pipeline.data["train"][None].get_current_value(2).var
             self.assertEqual(loaded_var, new_var2)
